/* SPDX-License-Identifier: LGPL-2.1+ */

#ifndef __LXC_VERSION_H
#define __LXC_VERSION_H

#define LXC_DEVEL 0
#define LXC_VERSION_MAJOR 6
#define LXC_VERSION_MINOR 0
#define LXC_VERSION_MICRO 4
#define LXC_VERSION_ABI "1.8.0"
#define LXC_VERSION "6.0.4"

#endif
